import { 
  select, 
  csv, 
  scaleLinear, 
  extent,  
  axisLeft,
  axisBottom,
  scaleTime,
  line,
  curveBasis,
} from "d3";

const svg = select("svg");

const height = +svg.attr("height");
const width = +svg.attr("width");

const render = data => {
  const title = "Eine Woche Tankdaten: Diesel";
	
  const xValue = d => d.date;
  const xAxisLabel = "Wochentage";
	
  const yValue = d => d.diesel;
  const yAxisLabel = "Preis";
  
  const margin = {top:60, right:50, bottom:88, left:125};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height -margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data,xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data,yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(20);
  
 const yAxisG = g.append('g').call(yAxis);
 yAxisG.selectAll('.domain').remove();
  
 yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -80)
  	.attr('x', -innerHeight / 2)
  	.attr('fill', 'black')
  	.attr('transform', `rotate(-90)`)
  	.style('text-anchor', 'middle')
  	.text(yAxisLabel);
  
 const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
  	
 xAxisG.select('.domain').remove();
  
 xAxisG.append('text')
   .attr('class', 'axis-label')
   .attr('y', 70)
   .attr('x', innerWidth/2)
   .attr('fill', 'black')
   .text(xAxisLabel);
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
 	  .y(d => yScale(yValue(d)))
    .curve(curveBasis);
  
  g.append('path')
  	.attr('class','line-path')
  	.attr('d', lineGenerator(data));
	
  g.append('text')
  	 .attr('class', 'title')
  	 .attr('y', -10)
  	 .text(title);
};

csv('data.csv')
  .then(data =>{
 		data.forEach(d => {
      d.date = new Date(d.date);
      d.diesel = +d.diesel;
      //d.dieselchange = +d.dieselchange;
      //d.e5 = +d.e5;
      //d.e5change = +d.e5change;
      //d.e10 = +d.e10;
      //d.e10change = +d.e10change;
   });
  console.log(data);
  render(data);
});